const { spawn } = require('node:child_process');
const ls = spawn('luna-send', ['-i', 'luna://com.webos.service.tvpower/power2/getPowerState', '{ "subscribe": true }']);

function irTogglePower() {
    spawn('luna-send', ['-n', '1', 'luna://com.webos.service.irdbmanager/sendIrCommand', '{ "buttonState": "single", "deviceType": "audio", "keyCode": "IR_KEY_POWER"}']);
}

ls.stdout.on('data', stdout => {
    /**
     * @param {string} jsonString
     * @return {Stdout | null}
     */
    const saveJsonParse = jsonString => {
        if (!jsonString) return ''
        try {
            const json = JSON.parse(jsonString)
            return json
        } catch (error) {
            console.error(error);
            return null
        }
    }

    const messages = `${stdout}`.split('\n').map(saveJsonParse).filter(Boolean)

    messages.forEach(message => {
        if (
            (message['sub processing'] === 'screen on' && message.reason === 'remoteKey') ||
            (message['sub processing'] === 'screen on' && message.reason === 'wakeOnWiFi') ||
            (message['sub processing'] === 'screen on' && message.reason === 'onAoDByBT') ||
            (message['sub processing'] === 'screen on' && message.reason === 'wakeOnLan') ||
            (message['sub processing'] === 'prepare power off' && message.reason === 'remoteKey') ||
            (message['sub processing'] === 'prepare power off' && message.reason === 'aod30sec')
        ) {
            irTogglePower()
        }
    })
});

ls.stderr.on('data', (data) => {
    console.error(`stderr: ${data}`);
});

ls.on('close', (code) => {
    console.log(`child process exited with code ${code}`);
});